@@ -1,6 +1,5 @@
-#include <term.h>
 #include <curses.h>
-#include "bug2.h"
+#include "bug3.h"
 
 void init(void)
 {
@@ -18,15 +17,12 @@ void start(void)
 	int loop, loop2;
 
 	// place blocks ..
-	attron(A_DIM);
 	for(loop = 1; loop <= NUM_BLOCKS; loop++)
 		mvwprintw(world_pad, getrandom(0,world_row-1),getrandom(0,world_col-1),"%c",BLOCK);
-	attroff(A_DIM);
 	
 	// place food
 	for(loop = 1; loop <= NUM_FOOD; loop++)
 		placefood();
-	refresh();
 	
 	// create bugs
 	for(loop = 1; loop <= NUM_BUGS; loop++)
@@ -38,11 +34,19 @@ void start(void)
 		temp->vector = getrandom(0,3);
 		temp->food = INIT_FOOD;
 		temp->food_type = FOOD3;
+		temp->predlvl = 0;
+		temp->size = getrandom (MIN_SIZE, MAX_SIZE);
 		temp->race = (char) getrandom(LOW_RACE,HIGH_RACE);
 		temp->generation = 1;
 		temp->age = 0;
 		for(loop2 = 0; loop2 <= S_LEN; loop2++)
+		{
 			temp->search[loop2] = getrandom(0,3);
+			if (temp->search[loop2] == 0)
+				temp->predlvl--;
+			if (temp->search[loop2] == 3)
+				temp->predlvl++;
+		}
 		if(loop == 1)
 			bugs = temp;
 		else
