@@ -1,11 +1,31 @@
 #include <curses.h>
-#include "bug2.h"
+#include "bug3.h"
+
+int isbug(char temp)
+{
+	if ((temp == FOOD1)||(temp == FOOD2)||(temp == FOOD3)||(temp == BLOCK)||(temp == SPACE))
+		return(0);
+	else
+		return(1);
+}
+
+int motivate(char temp)
+{
+	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
+		return(1);
+	
+	if((temp != bugs->race)&&(isbug(temp)))
+		return(bugs->predlvl);
+	
+	return(0);
+}
 
 int look(int search)
 {
 	struct bug *eaten;
 	char temp;
 	int leftw = 0, rightw = 0, forwardw = 0;
+	int ifhit;
 	
 	// look for mate and/or food
 	
@@ -19,180 +39,135 @@ int look(int search)
 	
 	if(temp == bugs->food_type)
 	{
-		if(bugs->race == PREDITOR)
-		{
-			switch(bugs->vector)
-			{
-				case 0:
-					// screen up
-					eaten = findbug((bugs->ypos - 1 + world_row) % world_row,bugs->xpos);
-					break;
-				case 1:
-					// screen right
-					eaten = findbug(bugs->ypos,(bugs->xpos + 1) % world_col);
-					break;
-				case 2:
-					// screen down
-					eaten = findbug((bugs->ypos + 1) % world_row,bugs->xpos);
-					break;
-				case 3: 
-					// screen left
-					eaten = findbug(bugs->ypos,(bugs->xpos - 1 + world_col) % world_col);
-					break;                                          
-				default:
-					fprintf(stderr, "default in perditor eat bugs->vector is bad\n");
-					break;
-			}
-			if(DEBUG)
-				fprintf(stderr,"biten\n");
-			eaten->food -= BITE_SIZE;
-			if(eaten->food <= 0)
-			{
-				bugs->food += BUG_FOOD;
-				die(eaten);
-			}
-			return WAIT;
-		}
-		else
-		{
-			placefood();  
-			bugs->food++;
-			return FORWARD;
-		}
+		placefood();  
+		bugs->food += FOOD_FOOD;
+		return FORWARD;
 	}
 	
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		forwardw--;
+	if((temp != bugs->race)&&(isbug(temp))&&(bugs->predlvl > -BUG_PRED))
+	{
+		switch(bugs->vector)
+		{
+			case 0:
+				// screen up
+				eaten = findbug((bugs->ypos - 1 + world_row) % world_row,bugs->xpos);
+				break;
+			case 1:
+				// screen right
+				eaten = findbug(bugs->ypos,(bugs->xpos + 1) % world_col);
+				break;
+			case 2:
+				// screen down
+				eaten = findbug((bugs->ypos + 1) % world_row,bugs->xpos);
+				break;
+			case 3: 
+				// screen left
+				eaten = findbug(bugs->ypos,(bugs->xpos - 1 + world_col) % world_col);
+				break;                                          
+			default:
+				fprintf(stderr, "default in perditor eat bugs->vector is bad\n");
+				break;
+		}
+		
+		ifhit = eaten->predlvl < bugs->predlvl ? getrandom(eaten->predlvl, bugs->predlvl) : getrandom(bugs->predlvl, eaten->predlvl);
+		if (ifhit > 0)
+		{
+			eaten->food -= (BITE_SIZE*bugs->size/eaten->size);
+			if(eaten->food <= 0)
+			{
+				bugs->food += BUG_FOOD*eaten->size;
+				bugs->predlvl++;
+				if (bugs->predlvl > BUG_PRED)
+					bugs->food_type = '\0';
+				die(eaten);
+			}
+			else if (eaten->predlvl < 0)
+				eaten->predlvl--;
+		}
 
+		return WAIT;
+	}
+	
 	// listen in back for preditor ...
 	temp = peek(-1,0);
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		forwardw += RUN * 2;
+	if((temp != bugs->race)&&(isbug(temp)))
+		forwardw += bugs->predlvl * 2;
 	temp = peek(-2,0);
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		forwardw += RUN;
+	if((temp != bugs->race)&&(isbug(temp)))
+		forwardw += bugs->predlvl;
 	temp = peek(-1,1);
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		forwardw += RUN;
+	if((temp != bugs->race)&&(isbug(temp)))
+		forwardw += bugs->predlvl;
 	temp = peek(-1,-1);
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		forwardw += RUN;
+	if((temp != bugs->race)&&(isbug(temp)))
+		forwardw += bugs->predlvl;
 	// end listen ...
 
 	temp = peek(1,0);
 	if(temp == SPACE)
 	{       
 		temp = peek(2,0);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			forwardw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			forwardw--;
+		forwardw += motivate(temp);
 
 		if(temp == SPACE)
 		{       
 			temp = peek(3,0);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				forwardw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				forwardw--;
+			forwardw += motivate(temp);
 
 			temp = peek(2,-1);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				forwardw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				forwardw--;
+			forwardw += motivate(temp);
 
 			temp = peek(2,1);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				forwardw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				forwardw--;
-
+			forwardw += motivate(temp);
 		}
 		
 		temp = peek(1,-1);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			forwardw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			forwardw--;
+		forwardw += motivate(temp);
 
 		temp = peek(1,-1);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			forwardw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			forwardw--;
+		forwardw += motivate(temp);
 	}
 			
 	temp = peek(0,-1);
-	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-		leftw++;
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		leftw--;
+	leftw += motivate(temp);
 
 	if(temp == SPACE)
 	{
 		temp = peek(0,-2);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			leftw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			leftw--;
-	
+		leftw += motivate(temp);
+		
 		if(temp == SPACE)
 		{
 			temp = peek(0,-3);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				leftw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				leftw--;
-	
+			leftw += motivate(temp);
+		
 			temp = peek(1,-2);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				leftw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				leftw--;
+			leftw += motivate(temp);
 		}
 
 		temp = peek(1,-1);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			leftw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			leftw--;
+		leftw += motivate(temp);
 	}
 	
 	temp = peek(0,1);
-	if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-		rightw++;
-	if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-		rightw--;
+	rightw += motivate(temp);
 
 	if(temp == SPACE)
 	{
 		temp = peek(0,2);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			rightw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			rightw--;
+		rightw += motivate(temp);
 
 		if(temp == SPACE)
 		{
 			temp = peek(0,3);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				rightw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				rightw--;
+			rightw += motivate(temp);
 
 			temp = peek(1,2);
-			if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-				rightw++;
-			if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-				rightw--;
+			rightw += motivate(temp);
 		}
 
 		temp = peek(1,1);
-		if(((temp == bugs->race)&&(bugs->food > INIT_FOOD + MATE_COST))||((temp == bugs->food_type)&&(bugs->food < INIT_FOOD * 2)))
-			rightw++;
-		if((temp == PREDITOR)&&(bugs->race != PREDITOR))
-			rightw--;
+		rightw += motivate(temp);
 	}
 	
 	temp = peek(1,0);
@@ -303,5 +278,5 @@ char peek(int fw, int lr)
 			fprintf(stderr,"default in peek bugs->vector is bad\n");
 			break;   
 	}
-	return temp[0];
+	return toupper(temp[0]);
 }
